# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/fewsats-python',
                'doc_host': 'https://Fewsats.github.io',
                'git_url': 'https://github.com/Fewsats/fewsats-python',
                'lib_path': 'fewsats'},
  'syms': { 'fewsats.core': { 'fewsats.core.Fewsats': ('core.html#fewsats', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.__init__': ('core.html#fewsats.__init__', 'fewsats/core.py'),
                              'fewsats.core.Fewsats._preview_payment': ('core.html#fewsats._preview_payment', 'fewsats/core.py'),
                              'fewsats.core.Fewsats._request': ('core.html#fewsats._request', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.as_tools': ('core.html#fewsats.as_tools', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.balance': ('core.html#fewsats.balance', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.create_offers': ('core.html#fewsats.create_offers', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.get_payment_details': ('core.html#fewsats.get_payment_details', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.get_payment_status': ('core.html#fewsats.get_payment_status', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.me': ('core.html#fewsats.me', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.pay_lightning': ('core.html#fewsats.pay_lightning', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.pay_offer': ('core.html#fewsats.pay_offer', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.pay_offer_str': ('core.html#fewsats.pay_offer_str', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.payment_info': ('core.html#fewsats.payment_info', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.payment_methods': ('core.html#fewsats.payment_methods', 'fewsats/core.py'),
                              'fewsats.core.Fewsats.set_webhook': ('core.html#fewsats.set_webhook', 'fewsats/core.py'),
                              'fewsats.core.L402Offers': ('core.html#l402offers', 'fewsats/core.py'),
                              'fewsats.core.L402Offers.__init__': ('core.html#l402offers.__init__', 'fewsats/core.py'),
                              'fewsats.core.L402Offers.__repr__': ('core.html#l402offers.__repr__', 'fewsats/core.py'),
                              'fewsats.core.L402Offers.as_dict': ('core.html#l402offers.as_dict', 'fewsats/core.py'),
                              'fewsats.core.L402Offers.from_dict': ('core.html#l402offers.from_dict', 'fewsats/core.py'),
                              'fewsats.core.Offer': ('core.html#offer', 'fewsats/core.py'),
                              'fewsats.core.Offer.__init__': ('core.html#offer.__init__', 'fewsats/core.py'),
                              'fewsats.core.Offer.__repr__': ('core.html#offer.__repr__', 'fewsats/core.py'),
                              'fewsats.core.Offer.from_dict': ('core.html#offer.from_dict', 'fewsats/core.py')},
            'fewsats.l402': { 'fewsats.l402.L.starstarmap': ('claudette.html#l.starstarmap', 'fewsats/l402.py'),
                              'fewsats.l402.Offer': ('claudette.html#offer', 'fewsats/l402.py'),
                              'fewsats.l402.Offer.__init__': ('claudette.html#offer.__init__', 'fewsats/l402.py'),
                              'fewsats.l402.Offer.supports': ('claudette.html#offer.supports', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentInfo': ('claudette.html#paymentinfo', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentInfo.__init__': ('claudette.html#paymentinfo.__init__', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentOffers': ('claudette.html#paymentoffers', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentOffers.__init__': ('claudette.html#paymentoffers.__init__', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentOffers.__str__': ('claudette.html#paymentoffers.__str__', 'fewsats/l402.py'),
                              'fewsats.l402.PaymentOffers.by_payment': ('claudette.html#paymentoffers.by_payment', 'fewsats/l402.py'),
                              'fewsats.l402.get_payment_details': ('claudette.html#get_payment_details', 'fewsats/l402.py')}}}
